"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const read_config_1 = __importDefault(require("../utils/read-config"));
const review_project_1 = __importDefault(require("../utils/review-project"));
const dependents_to_string_1 = __importDefault(require("../utils/dependents-to-string"));
module.exports = {
    name: 'addon-guard',
    description: 'Review project to ensure that no addon dependency conflicts are present.',
    works: 'insideProject',
    // TODO - add options?
    // availableOptions: Object.freeze([]),
    run( /* options: any */) {
        const config = read_config_1.default(this.project);
        const options = {
            ignoreAddons: config.ignoreAddons || [],
            runtimeOnly: true,
            conflictsOnly: true,
            skipCacheKeyDependencyChecks: config.skipCacheKeyDependencyChecks
        };
        const summary = review_project_1.default(this.project, options);
        const addons = summary.addons;
        const addonCount = Object.keys(addons).length;
        if (addonCount > 0) {
            this.ui.writeLine(chalk_1.default.white(`${addonCount} addons identified by ember-cli-addon-guard:\n`));
            for (const name in addons) {
                const addonInstances = addons[name];
                this.ui.writeLine(chalk_1.default.underline(`${name}`));
                this.ui.writeLine(dependents_to_string_1.default(name, addonInstances));
            }
        }
        else {
            this.ui.writeLine(chalk_1.default.green(`No matching addons were found by ember-cli-addon-guard.`));
        }
    }
};
//# sourceMappingURL=addon-guard.js.map